Learn R Programming

MRTAnalysis (version 0.4.1)

.mcee_check_dp_strictly_increasing: Check that decision points are strictly increasing within each subject

Description

Check that decision points are strictly increasing within each subject

Usage

.mcee_check_dp_strictly_increasing(data, id, dp)

Value

Invisibly TRUE if valid, otherwise stops with error

Arguments

data

Data frame

id

Column name for subject ID

dp

Column name for decision point