.mcee_check_id_rows_grouped: Check that rows for each subject appear in contiguous blocks
Description
Check that rows for each subject appear in contiguous blocks
Usage
.mcee_check_id_rows_grouped(data, id, max_show = 5)
Value
Invisibly TRUE if valid, otherwise stops with error
Arguments
- data
Data frame
- id
Column name for subject ID
- max_show
Maximum number of offending IDs to show in error message