.mcee_check_outcome_constant_within_id: Check that outcome is constant within each subject (required for distal outcomes)
Description
Check that outcome is constant within each subject (required for distal outcomes)
Usage
.mcee_check_outcome_constant_within_id(data, id, outcome)
Value
Invisibly TRUE if valid, otherwise stops with error
Arguments
- data
Data frame
- id
Column name for subject ID
- outcome
Column name for outcome